@@ -6,6 +6,7 @@ Task test cases
 @license: GPL v3 or later
 """
 import unittest
+from unittest.mock import patch
 
 import testutils
 
@@ -40,7 +41,7 @@ class TaskTestCase(unittest.TestCase):
         expected = ["t1", "t2"]
         self.assertEqual(result, expected)
 
-        kwDict = self.session.query(Task).get(2).getKeywordDict()
+        kwDict = self.session.get(Task, 2).getKeywordDict()
         self.assertEqual(kwDict, dict(kw1=None, kw2=12))
 
         for bad_input in ("",  # No project
@@ -54,7 +55,7 @@ class TaskTestCase(unittest.TestCase):
         tui.addInputAnswers("newtxt")
         self.cmd.do_t_edit("1")
 
-        task = self.session.query(Task).get(1)
+        task = self.session.get(Task, 1)
         self.assertEqual(task.title, "newtxt")
         self.assertEqual(task.getKeywordDict(), {"_note": None})
 
@@ -65,7 +66,7 @@ class TaskTestCase(unittest.TestCase):
         tui.addInputAnswers("txt @kw", "y")
         self.cmd.do_t_edit("1")
 
-        task = self.session.query(Task).get(1)
+        task = self.session.get(Task, 1)
         self.assertEqual(task.title, "txt")
         self.assertEqual(task.getKeywordDict(), {"kw": None})
 
@@ -76,7 +77,7 @@ class TaskTestCase(unittest.TestCase):
         tui.addInputAnswers("txt")
         self.cmd.do_t_edit("1")
 
-        task = self.session.query(Task).get(1)
+        task = self.session.get(Task, 1)
         self.assertEqual(task.title, "txt")
         self.assertEqual(task.getKeywordDict(), {})
 
@@ -111,7 +112,7 @@ class TaskTestCase(unittest.TestCase):
     def testMark(self):
         tui.addInputAnswers("y")
         self.cmd.do_t_add("x t1")
-        task = self.session.query(Task).get(1)
+        task = self.session.get(Task, 1)
         self.assertEqual(task.status, "new")
         self.cmd.do_t_mark_started("1")
         self.assertEqual(task.status, "started")
@@ -123,7 +124,7 @@ class TaskTestCase(unittest.TestCase):
     def testAddKeywords(self):
         tui.addInputAnswers("y")
         self.cmd.do_t_add("x t1")
-        task = self.session.query(Task).get(1)
+        task = self.session.get(Task, 1)
 
         tui.addInputAnswers("y", "y")
         self.cmd.do_t_add_keywords("1 @kw1 @kw2=12")
@@ -141,17 +142,17 @@ class TaskTestCase(unittest.TestCase):
         self.cmd.do_t_add("x t1")
         tui.addInputAnswers("y")
         self.cmd.do_t_project("1 y")
-        task1 = self.session.query(Task).get(1)
+        task1 = self.session.get(Task, 1)
         self.assertEqual(task1.project.name, "y")
 
         self.cmd.do_t_add("x t2")
         self.cmd.do_t_project("1 _")
-        task1 = self.session.query(Task).get(1)
+        task1 = self.session.get(Task, 1)
         self.assertEqual(task1.project.name, "x")
 
         tui.addInputAnswers("n")
         self.cmd.do_t_project("1 doesnotexist")
-        task1 = self.session.query(Task).get(1)
+        task1 = self.session.get(Task, 1)
         self.assertEqual(task1.project.name, "x")
 
     def testLastTaskId(self):
@@ -160,11 +161,11 @@ class TaskTestCase(unittest.TestCase):
 
         tui.addInputAnswers("y")
         self.cmd.do_t_add("x t1")
-        task1 = self.session.query(Task).get(1)
+        task1 = self.session.get(Task, 1)
         self.assertEqual(self.cmd.getTaskFromId("_"), task1)
 
         self.cmd.do_t_add("x t2")
-        task2 = self.session.query(Task).get(2)
+        task2 = self.session.get(Task, 2)
         self.assertEqual(self.cmd.getTaskFromId("_"), task2)
 
         self.cmd.do_t_mark_started("1")
@@ -175,15 +176,15 @@ class TaskTestCase(unittest.TestCase):
         self.assertRaises(YokadiException, self.cmd.do_t_add, "_ t1")
         tui.addInputAnswers("y")
         self.cmd.do_t_add("x t1")
-        task1 = self.session.query(Task).get(1)
+        task1 = self.session.get(Task, 1)
         self.cmd.do_t_add("_ t2")
-        task2 = self.session.query(Task).get(2)
+        task2 = self.session.get(Task, 2)
         self.assertEqual(task1.project, task2.project)
 
     def testRecurs(self):
         tui.addInputAnswers("y")
         self.cmd.do_t_add("x t1")
-        task = self.session.query(Task).get(1)
+        task = self.session.get(Task, 1)
 
         self.cmd.do_t_recurs("1 daily 10:00")
         self.assertTrue(task.recurrence)
@@ -312,7 +313,7 @@ class TaskTestCase(unittest.TestCase):
         ids = [1, 2, 4, 5, 6, 9]
         self.cmd.do_t_apply("1 2,4-6 9 t_add_keywords @lala")
         for taskId in range(1, 10):
-            kwDict = self.session.query(Task).get(taskId).getKeywordDict()
+            kwDict = self.session.get(Task, taskId).getKeywordDict()
             if taskId in ids:
                 self.assertEqual(kwDict, dict(lala=None))
             else:
@@ -324,13 +325,13 @@ class TaskTestCase(unittest.TestCase):
         self.cmd.do_t_list("@lala")
         self.cmd.do_t_apply("__ t_add_keywords @toto")
         for taskId in range(1, 10):
-            kwDict = self.session.query(Task).get(taskId).getKeywordDict()
+            kwDict = self.session.get(Task, taskId).getKeywordDict()
             if taskId in ids:
                 self.assertEqual(kwDict, dict(lala=None, toto=None))
             else:
                 self.assertNotEqual(kwDict, dict(lala=None, toto=None))
 
-    def testReorder(self):
+    def testReorderFailsOnInvalidInputs(self):
         self.assertRaises(BadUsageException, self.cmd.do_t_reorder, "unknown_project")
         self.assertRaises(BadUsageException, self.cmd.do_t_reorder, "too much args")
 
@@ -347,12 +348,12 @@ class TaskTestCase(unittest.TestCase):
         self.cmd.do_t_add("x t1")
 
         self.cmd.do_t_to_note(1)
-        task = self.session.query(Task).get(1)
+        task = self.session.get(Task, 1)
         self.assertTrue(task.isNote(self.session))
 
         # Doing it twice should not fail
         self.cmd.do_t_to_note(1)
-        task = self.session.query(Task).get(1)
+        task = self.session.get(Task, 1)
         self.assertTrue(task.isNote(self.session))
 
     def testToTask(self):
@@ -360,12 +361,26 @@ class TaskTestCase(unittest.TestCase):
         self.cmd.do_n_add("x t1")
 
         self.cmd.do_n_to_task(1)
-        task = self.session.query(Task).get(1)
+        task = self.session.get(Task, 1)
         self.assertFalse(task.isNote(self.session))
 
         # Doing it twice should not fail
         self.cmd.do_n_to_task(1)
-        task = self.session.query(Task).get(1)
+        task = self.session.get(Task, 1)
         self.assertFalse(task.isNote(self.session))
 
+    @patch("yokadi.ycli.tui.editText")
+    def testReorder(self, editTextMock):
+        t1, t2, t3 = [dbutils.addTask("x", f"t{x}", interactive=False) for x in range(1, 4)]
+
+        # Simulate moving t3 from 3rd line to the 1st
+        editTextMock.return_value = "3,t3\n1,t1\n2,t2"
+
+        self.cmd.do_t_reorder("x")
+        editTextMock.assert_called_with("1,t1\n2,t2\n3,t3")
+
+        self.assertEqual(t3.urgency, 2)
+        self.assertEqual(t1.urgency, 1)
+        self.assertEqual(t2.urgency, 0)
+
 # vi: ts=4 sw=4 et
