@@ -16,7 +16,10 @@ class TuiTestCase(unittest.TestCase):
         tui.clearInputAnswers()
 
     def testEditEmptyText(self):
-        os.environ["EDITOR"] = "/bin/true"
+        # Add an unused input answer to pass the isInteractive() check in editText()
+        tui.addInputAnswers("")
+
+        os.environ["EDITOR"] = "/usr/bin/true"
         out = tui.editText(None)
         self.assertEqual(out, "")
 
